@@ -1348,6 +1348,9 @@ GPBOOST_C_EXPORT int LGBM_NetworkInitWithFunctions(int num_machines,
 * \param matrix_inversion_method Method which is used for matrix inversion
 * \param seed Seed used for model creation (e.g., random ordering in Vecchia approximation)
 * \param num_parallel_threads Number of parallel threads for OMP
+* \param has_weights True, if sample weights should be used
+* \param weights Sample weights
+* \param likelihood_learning_rate Likelihood learning rate for generalized Bayesian inference (only non-Gaussian likelihoods)
 * \param[out] out Created REModel
 * \return 0 when succeed, -1 when failure happens
 */
@@ -1379,6 +1382,9 @@ GPBOOST_C_EXPORT int GPB_CreateREModel(int32_t num_data,
     const char* matrix_inversion_method,
     int seed,
     int num_parallel_threads,
+    bool has_weights,
+    const double* weights,
+    double likelihood_learning_rate,
     REModelHandle* out);
 
 /*!
@@ -1418,6 +1424,7 @@ GPBOOST_C_EXPORT int GPB_REModelFree(REModelHandle handle);
 * \param piv_chol_rank Rank of the pivoted cholseky decomposition used as preconditioner of the conjugate gradient algorithm
 * \param init_aux_pars Initial values for values for aux_pars_ (e.g., shape parameter of gamma likelihood)
 * \param estimate_aux_pars If true, any additional parameters for non-Gaussian likelihoods are also estimated (e.g., shape parameter of gamma likelihood)
+* \param estimate_cov_par_index If estimate_cov_par_index[0] >= 0, some covariance parameters might not be estimated, estimate_cov_par_index[i] is then bool and indicates which ones are estimated
 * \return 0 when succeed, -1 when failure happens
 */
 GPBOOST_C_EXPORT int GPB_SetOptimConfig(REModelHandle handle,
@@ -1447,7 +1454,8 @@ GPBOOST_C_EXPORT int GPB_SetOptimConfig(REModelHandle handle,
     int seed_rand_vec_trace,
     int piv_chol_rank,
     double* init_aux_pars,
-    bool estimate_aux_pars);
+    bool estimate_aux_pars,
+    const int* estimate_cov_par_index);
 
 /*!
 * \brief Find parameters that minimize the negative log-ligelihood (=MLE)
